# GENERATED FILE - DO NOT EDIT
VERSION = '202004291642'
BUILDS = {'Darwin': {'build_exception': '',
            'log': 'thor-OSXIntel64-202004291642.log',
            'sha256': '5dcc68e7a4cc77177de191873fc5e0f6dd8de319fc21ecd4290f11e274dd06e6',
            'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-OSXIntel64-202004291642.zip'},
 'Docker': {'tag': '202004291642'},
 'Linux': {'build_exception': '',
           'log': 'thor-Linux64-202004291642.log',
           'sha256': '59bfbc6d6fdbe2de024fc98c3d653c96968c5df4d4d5ba73afb6d2582bff2e0f',
           'url': 'http://s3-us-west-2.amazonaws.com/ai2-thor/builds/thor-Linux64-202004291642.zip'}}